pub struct FeePreview {
pub asin: Option<String>,
pub price: Option<Box<MoneyType>>,
pub fee_breakdown: Option<Vec<FeeLineItem>>,
pub total_fees: Option<Box<MoneyType>>,
pub errors: Option<Vec<Error>>,
}Expand description
FeePreview : The fee estimate for a specific item.
Fields
asin: Option<String>The Amazon Standard Identification Number (ASIN) value used to identify the item.
price: Option<Box<MoneyType>>fee_breakdown: Option<Vec<FeeLineItem>>A list of the Small and Light fees for the item.
total_fees: Option<Box<MoneyType>>errors: Option<Vec<Error>>One or more unexpected errors occurred during the getSmallAndLightFeePreview operation.
Implementations
sourceimpl FeePreview
impl FeePreview
sourcepub fn new() -> FeePreview
pub fn new() -> FeePreview
The fee estimate for a specific item.